@@ -2,6 +2,9 @@
 #'
 #' Obtain the Xenopus tail single-cell RNA-seq data from Aztekin et al. (2019).
 #'
+#' @param legacy Logical scalar indicating whether to pull data from ExperimentHub.
+#' By default, we use data from the gypsum backend.
+#'
 #' @details
 #' Column metadata is provided in the same form as supplied in E-MTAB-7761.
 #' This contains information such as the treatment condition, batch, putative cell type, putative cell cycle phase.
@@ -26,13 +29,18 @@
 #' @export
 #' @importFrom SingleCellExperiment splitAltExps reducedDim<- 
 #' @importFrom SummarizedExperiment colData colData<-
-AztekinTailData <- function() {
-    version <- "2.0.0"
-    sce <- .create_sce(file.path("aztekin-tail", version), has.rowdata=FALSE)
+AztekinTailData <- function(legacy=FALSE) {
+    if (!legacy) {
+        sce <- fetchDataset("aztekin-tail-2019", "2023-12-14", realize.assays=TRUE)
 
-    # Move UMAP coordinates to the reducedDims.
-    reducedDim(sce, "UMAP") <- as.matrix(colData(sce)[,c("X", "Y")])
-    colData(sce) <- colData(sce)[,setdiff(colnames(colData(sce)), c("X", "Y"))]
+    } else {
+        version <- "2.0.0"
+        sce <- .create_sce(file.path("aztekin-tail", version), has.rowdata=FALSE)
+
+        # Move UMAP coordinates to the reducedDims.
+        reducedDim(sce, "UMAP") <- as.matrix(colData(sce)[,c("X", "Y")])
+        colData(sce) <- colData(sce)[,setdiff(colnames(colData(sce)), c("X", "Y"))]
+    }
 
     sce
 }
