@@ -8,6 +8,8 @@
 #' Only used if \code{volume} is specified.
 #' @param mix String specifying whether to compute the number of molecules for mix 1 or 2.
 #' Only used if both \code{dilution} and \code{volume} are specified.
+#' @param legacy Logical scalar indicating whether to pull data from ExperimentHub.
+#' By default, we use data from the gypsum backend.
 #'
 #' @details
 #' If \code{volume} and \code{dilution} are specified,
@@ -27,15 +29,19 @@
 #' @export
 #' @importFrom utils read.delim
 #' @importFrom SingleCellExperiment splitAltExps
-ERCCSpikeInConcentrations <- function(volume = NULL, dilution = NULL, mix=c("1", "2")) {
-    version <- "2.0.0"
-    hub <- .ExperimentHub()
-    host <- "scRNAseq/ercc-concentrations"
-    file <- hub[hub$rdatapath==file.path(host, "2.2.0", "cms_095046.txt")][[1]]
+ERCCSpikeInConcentrations <- function(volume = NULL, dilution = NULL, mix=c("1", "2"), legacy=FALSE) {
+    if (!legacy) {
+        table <- fetchDataset("ercc", "2023-12-20")
+    } else {
+        version <- "2.0.0"
+        hub <- ExperimentHub()
+        host <- "scRNAseq/ercc-concentrations"
+        file <- hub[hub$rdatapath==file.path(host, "2.2.0", "cms_095046.txt")][[1]]
 
-    table <- read.delim(file, check.names = FALSE)
-    rownames(table) <- table[,"ERCC ID"]
-    table <- table[,-(1:2)]
+        table <- read.delim(file, check.names = FALSE)
+        rownames(table) <- table[,"ERCC ID"]
+        table <- table[,-(1:2)]
+    }
 
     if (!is.null(volume) && !is.null(dilution)) {
         field <- sprintf("concentration in Mix %s (attomoles/ul)", match.arg(mix))
