@@ -5,6 +5,8 @@
 #' @param mode Character vector specifying whether to return either or both the RNA and ADT counts.
 #' @param ensembl Logical scalar indicating whether the output row names should contain Ensembl identifiers.
 #' @param location Logical scalar indicating whether genomic coordinates should be returned.
+#' @param legacy Logical scalar indicating whether to pull data from ExperimentHub.
+#' By default, we use data from the gypsum backend.
 #' 
 #' @details
 #' This dataset contains 20 samples from 2 experimental batches, where each batch contains 5 high and 5 low responders. 
@@ -54,29 +56,35 @@
 #' @importFrom ExperimentHub ExperimentHub
 #' @importFrom SummarizedExperiment colData<-
 #' @importFrom SingleCellExperiment SingleCellExperiment altExps 
-KotliarovPBMCData <- function(mode=c("rna", "adt"), ensembl=FALSE, location=TRUE) {
+KotliarovPBMCData <- function(mode=c("rna", "adt"), ensembl=FALSE, location=TRUE, legacy=FALSE) {
     mode <- match.arg(mode, c("rna", "adt"), several.ok=TRUE)
-    version <- "2.4.0"
-    tag <- "kotliarov-pbmc"
-    hub <- .ExperimentHub()
-    
-    collated <- list()
-    for (x in mode) {
-        collated[[x]] <- .create_sce(file.path(tag, version), hub=hub, 
-            has.rowdata=FALSE, has.coldata=FALSE, suffix=x)
-    }
 
-    if ("rna" %in% names(collated)) {
-        collated[["rna"]] <- .convert_to_ensembl(collated[["rna"]],
-            symbols=rownames(collated[["rna"]]),
-            species="Hs",
-            ensembl=ensembl,
-            location=location)
+    if (!legacy && identical(mode, c("rna", "adt"))) {
+        sce <- fetchDataset("kotliarov-pbmc-2020", "2024-04-18", realize.assays=TRUE)
+
+    } else {
+        version <- "2.4.0"
+        tag <- "kotliarov-pbmc"
+        hub <- ExperimentHub()
+        
+        collated <- list()
+        for (x in mode) {
+            collated[[x]] <- .create_sce(file.path(tag, version), hub=hub, 
+                has.rowdata=FALSE, has.coldata=FALSE, suffix=x)
+        }
+
+        if ("rna" %in% names(collated)) {
+            collated[["rna"]] <- .convert_to_ensembl(collated[["rna"]],
+                symbols=rownames(collated[["rna"]]),
+                species="Hs",
+                ensembl=ensembl,
+                location=location)
+        }
+        
+        sce <- collated[[1]]
+        altExps(sce) <- collated[-1]
+        colData(sce) <- hub[hub$rdatapath==file.path("scRNAseq", tag, version, "coldata.rds")][[1]] 
     }
-    
-    sce <- collated[[1]]
-    altExps(sce) <- collated[-1]
-    colData(sce) <- hub[hub$rdatapath==file.path("scRNAseq", tag, version, "coldata.rds")][[1]] 
 
     sce
 }
