@@ -65,10 +65,5 @@
             ahub.id <- "AH73881"
         }
     }
-    .AnnotationHub()[[ahub.id]]
-}
-
-.AnnotationHub <- function() {
-    .move_cache("AnnotationHub", "ANNOTATION_HUB_CACHE")
-    AnnotationHub()
+    AnnotationHub()[[ahub.id]]
 }
